@@ -396,6 +396,16 @@ drive_door_is_open (int fd)
 #endif
 }
 
+/**
+ * nautilus_burn_drive_door_is_open:
+ * @drive: #NautilusBurnDrive
+ *
+ * Report the whether the drive door or tray is open.
+ *
+ * Returns: %TRUE if the drive door is open, otherwise return %FALSE.
+ *
+ * Since: 2.12
+ **/
 gboolean
 nautilus_burn_drive_door_is_open (NautilusBurnDrive *drive)
 {
@@ -441,7 +451,7 @@ get_disc_type (const char *dev_path)
 		return -1;
 	}
 
-	if (ioctl (fd, CDROMREADTOCHDR, &header) == 0) {
+	if (ioctl (fd, CDROMREADTOCHDR, &header) < 0) {
 		return -1;
 	}
 
@@ -452,7 +462,7 @@ get_disc_type (const char *dev_path)
 	     entry.cdte_track++) {
 		entry.cdte_format = CDROM_LBA;
 		if (ioctl (fd, CDROMREADTOCENTRY, &entry) == 0) {
-			if (entry.cdte_ctrl & CDROM_DATA_TRACK) {
+			if (!(entry.cdte_ctrl & CDROM_DATA_TRACK)) {
 				type = CDS_AUDIO;
 				break;
 			}
@@ -481,7 +491,7 @@ get_disc_type (const char *dev_path)
 	    	return -1;
 	}
 
-	if (ioctl (fd, CDIOREADTOCHEADER, &header) == 0) {
+	if (ioctl (fd, CDIOREADTOCHEADER, &header) < 0) {
 		close (fd);
 	    	return -1;
 	}
@@ -507,7 +517,7 @@ get_disc_type (const char *dev_path)
 		entries.starting_track = i;
 	    	entries.address_format = CD_LBA_FORMAT;
 		if (ioctl (fd, CDIOREADTOCENTRYS, &entries) == 0) {
-		    	if (entry.control & CDROM_DATA_TRACK) {
+		    	if (!(entry.control & CDROM_DATA_TRACK)) {
 			    	type = CDS_AUDIO;
 				break;
 			}
